@@ -34,12 +34,11 @@ class Akonadi::MarkAsCommandPrivate
 {
 public:
     MarkAsCommandPrivate()
-        : mMarkJobCount(0),
-          mFolderListJobCount(0),
-          mInvertMark(0),
-          mRecursive(false)
+        : mMarkJobCount(0)
+        , mFolderListJobCount(0)
+        , mInvertMark(0)
+        , mRecursive(false)
     {
-
     }
 
     Akonadi::Collection::List mFolders;
@@ -52,8 +51,8 @@ public:
 };
 
 MarkAsCommand::MarkAsCommand(const Akonadi::MessageStatus &targetStatus, const Akonadi::Item::List &msgList, bool invert, QObject *parent)
-    : CommandBase(parent),
-      d(new Akonadi::MarkAsCommandPrivate())
+    : CommandBase(parent)
+    , d(new Akonadi::MarkAsCommandPrivate())
 {
     d->mInvertMark = invert;
     d->mMessages = msgList;
@@ -63,8 +62,8 @@ MarkAsCommand::MarkAsCommand(const Akonadi::MessageStatus &targetStatus, const A
 }
 
 MarkAsCommand::MarkAsCommand(const Akonadi::MessageStatus &targetStatus, const Akonadi::Collection::List &folders, bool invert, bool recursive, QObject *parent)
-    : CommandBase(parent),
-      d(new Akonadi::MarkAsCommandPrivate())
+    : CommandBase(parent)
+    , d(new Akonadi::MarkAsCommandPrivate())
 {
     d->mInvertMark = invert;
     d->mFolders = folders;
@@ -109,7 +108,8 @@ void MarkAsCommand::slotFetchDone(KJob *job)
 
     Akonadi::ItemFetchJob *fjob = static_cast<Akonadi::ItemFetchJob *>(job);
     d->mMessages.clear();
-    foreach (const Akonadi::Item &item, fjob->items()) {
+    const auto items = fjob->items();
+    for (const Akonadi::Item &item : items) {
         Akonadi::MessageStatus status;
         status.setStatusFromFlags(item.flags());
         if (d->mInvertMark) {
@@ -138,7 +138,7 @@ void MarkAsCommand::slotFetchDone(KJob *job)
 void MarkAsCommand::execute()
 {
     if (d->mRecursive && !d->mFolders.isEmpty()) {
-        if (KMessageBox::questionYesNo(qobject_cast<QWidget*>(parent()),
+        if (KMessageBox::questionYesNo(qobject_cast<QWidget *>(parent()),
                                        i18n("Are you sure you want to mark all messages in this folder and all its subfolders?"),
                                        i18n("Mark All Recursively")) == KMessageBox::Yes) {
             Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(d->mFolders.first());
@@ -171,7 +171,7 @@ void MarkAsCommand::markMessages()
     }
 
     Akonadi::Item::List itemsToModify;
-    foreach (const Akonadi::Item &it, d->mMessages) {
+    for (const Akonadi::Item &it : qAsConst(d->mMessages)) {
         Akonadi::Item item(it);
 
         // be careful to only change the flags we want to change, not to overwrite them
@@ -191,7 +191,7 @@ void MarkAsCommand::markMessages()
 
     d->mMarkJobCount++;
     if (itemsToModify.isEmpty()) {
-        slotModifyItemDone(0);   // pretend we did something
+        slotModifyItemDone(nullptr);   // pretend we did something
     } else {
         Akonadi::ItemModifyJob *modifyJob = new Akonadi::ItemModifyJob(itemsToModify, this);
         modifyJob->setIgnorePayload(true);
@@ -212,4 +212,3 @@ void MarkAsCommand::slotModifyItemDone(KJob *job)
         emitResult(OK);
     }
 }
-
